@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 140.statistics.php 663 2010-03-22 12:36:59Z d00p $
+ * @version    $Id: 140.statistics.php 745 2010-04-08 10:28:48Z d00p $
  */
 
 return array(
@@ -40,9 +40,27 @@ return array(
 					'default' => false,
 					'save_method' => 'storeSettingField',
 					),
-				),
-			),
-		),
+				'system_awstats_path' => array(
+					'label' => $lng['serversettings']['awstats_path'],
+					'settinggroup' => 'system',
+					'varname' => 'awstats_path',
+					'type' => 'string',
+					'string_type' => 'dir',
+					'default' => '/usr/bin/',
+					'save_method' => 'storeSettingField',
+					),
+				'system_awstats_conf' => array(
+					'label' => $lng['serversettings']['awstats_conf'],
+					'settinggroup' => 'system',
+					'varname' => 'awstats_conf',
+					'type' => 'string',
+					'string_type' => 'dir',
+					'default' => '/etc/awstats/',
+					'save_method' => 'storeSettingField',
+					)
+				)
+			)
+		)
 	);
 
 ?>
\ No newline at end of file
