@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: install.php 921 2010-05-07 14:25:08Z EleRas $
+ * @version    $Id: install.php 957 2010-05-19 12:29:32Z EleRas $
  */
 
 /**
@@ -637,6 +637,7 @@ if(isset($_POST['installstep'])
 		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/lighttpd/froxlor-htpasswd/' WHERE `settinggroup` = 'system' AND `varname` = 'apacheconf_htpasswddir'");
 		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/init.d/lighttpd reload' WHERE `settinggroup` = 'system' AND `varname` = 'apachereload_command'");
 		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/lighttpd/lighttpd.pem' WHERE `settinggroup` = 'system' AND `varname` = 'ssl_cert_file'");
+		$ssettings = '';
 	}
 
 	// insert the lastcronrun to be the installation date
@@ -659,8 +660,7 @@ if(isset($_POST['installstep'])
 			 `port` = '80',
 			 `namevirtualhost_statement` = '1',
 			 `vhostcontainer` = '1', 
-			 `vhostcontainer_servername_statement` = '1',
-			 `specialsettings` = 'DocumentRoot \"".$db->escape(dirname(dirname(__FILE__))) . "\"'";
+			 `vhostcontainer_servername_statement` = '1'";
 	$db->query($query);
 	$defaultip = $db->insert_id();
 
