@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: update_0.9.inc.php 1035 2010-05-31 09:01:29Z d00p $
+ * @version    $Id: update_0.9.inc.php 1086 2010-06-14 07:58:38Z EleRas $
  */
 
 if(isFroxlorVersion('0.9-r0'))
@@ -775,4 +775,24 @@ if(isFroxlorVersion('0.9.7'))
 	updateToVersion('0.9.8');
 }
 
+if(isFroxlorVersion('0.9.8'))
+{
+	showUpdateStep("Updating from 0.9.8 to 0.9.9-svn1", false);
+
+	$update_defdns_mailentry = isset($_POST['update_defdns_mailentry']) ? '1' : '0';
+
+	showUpdateStep("Adding new settings");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'dns_createmailentry', '".(int)$update_defdns_mailentry."');");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.9-svn1');
+}
+
+if(isFroxlorVersion('0.9.9-svn1'))
+{
+	showUpdateStep("Updating from 0.9.9-svn1 to 0.9.9 final");
+	lastStepStatus(0);
+	updateToVersion('0.9.9');
+}
+
 ?>
