@@ -14,10 +14,10 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.getFormFieldDataBool.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: function.getFormFieldDataBool.php 793 2010-04-14 07:48:41Z d00p $
  */
 
-function getFormFieldDataBool($fieldname, $fielddata, $input)
+function getFormFieldDataBool($fieldname, $fielddata, &$input)
 {
 	if(isset($input[$fieldname]) && ($input[$fieldname] === '1' || $input[$fieldname] === 1 || $input[$fieldname] === true || strtolower($input[$fieldname]) === 'yes' || strtolower($input[$fieldname]) === 'ja'))
 	{
