@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.inserttask.php 419 2010-02-21 21:09:48Z d00p $
+ * @version    $Id: function.inserttask.php 1044 2010-06-02 05:57:44Z d00p $
  */
 
 /**
@@ -62,6 +62,17 @@ function inserttask($type, $param1 = '', $param2 = '', $param3 = '')
 		$db->query('INSERT INTO `' . TABLE_PANEL_TASKS . '` (`type`, `data`) VALUES ("6", "' . $db->escape($data) . '")');
 		$doupdate = true;
 	}
+	elseif($type == '7'
+			&& $param1 != ''
+			&& $param2 != '')
+	{
+		$data = Array();
+		$data['loginname'] = $param1;
+		$data['email'] = $param2;
+		$data = serialize($data);
+		$db->query('INSERT INTO `' . TABLE_PANEL_TASKS . '` (`type`, `data`) VALUES ("7", "' . $db->escape($data) . '")');
+		$doupdate = true;
+	}
 
 	if($doupdate === true
 	   && (int)$settings['system']['realtime_port'] !== 0
