@@ -14,7 +14,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: english.lng.php 1027 2010-05-31 06:04:51Z d00p $
+ * @version    $Id: english.lng.php 1087 2010-06-14 08:09:17Z d00p $
  */
 
 /**
@@ -256,6 +256,7 @@ $lng['question']['ftp_reallydelete'] = 'Do you really want to delete the FTP acc
 $lng['question']['mysql_reallydelete'] = 'Do you really want to delete the database %s? This cannot be undone!';
 $lng['question']['admin_configs_reallyrebuild'] = 'Do you really want to rebuild all config files?';
 $lng['question']['admin_customer_alsoremovefiles'] = 'Remove user files too?';
+$lng['question']['admin_customer_alsoremovemail'] = 'Completely remove email data from filesystem?';
 
 /**
  * Mails
@@ -1064,7 +1065,7 @@ $lng['aps']['nospecialchars'] = 'Special characters are not allowed in the searc
 $lng['aps']['noitemsfound'] = 'No Packages were found!';
 $lng['aps']['nopackagesinstalled'] = 'You haven\'t installed any package yet which could be shown.';
 $lng['aps']['instance_install'] = 'Package Installation pending';
-$lng['aps']['instance_task_active'] = 'Installation running at this moment';
+$lng['aps']['instance_task_active'] = 'Package is currently being processed';
 $lng['aps']['instance_success'] = 'Package is installed/was installed successfully';
 $lng['aps']['instance_error'] = 'Package isn\'t installed - there occured some errors on the Installation';
 $lng['aps']['instance_uninstall'] = 'Package Uninstallation pending';
@@ -1420,7 +1421,10 @@ $lng['redirect_desc']['rc_found'] = 'found';
 $lng['redirect_desc']['rc_seeother'] = 'see other';
 $lng['redirect_desc']['rc_tempred'] = 'temporary redirect';
 
-// ADDED UN FROXLOR 0.9.8
+// ADDED IN FROXLOR 0.9.8
 $lng['error']['exception'] = '%s';
 
+// ADDED IN FROXLOR 0.9.9-svn1
+$lng['serversettings']['mail_also_with_mxservers'] = 'Create mail-, imap-, pop3- and smtp-"A record" also with MX-Servers set';
+
 ?>
