@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 1024 2010-05-29 18:53:16Z EleRas $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1046 2010-06-04 05:50:23Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -677,7 +677,7 @@ class apache
 				}
 			}
 
-			mkDirWithCorrectOwnership($domain['customerroot'], $domain['documentroot'], $domain['guid'], $domain['guid'], true);
+			mkDirWithCorrectOwnership($domain['customerroot'], $domain['documentroot'], $domain['guid'], $domain['guid'], true, true);
 			$vhost_content.= $this->getWebroot($domain);
 			$vhost_content.= $this->composePhpOptions($domain);
 			$vhost_content.= $this->getStats($domain);
