@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.15.apache_fcgid.php 930 2010-05-12 06:52:11Z d00p $
+ * @version    $Id: cron_tasks.inc.http.15.apache_fcgid.php 952 2010-05-18 11:48:58Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -166,9 +166,20 @@ class apache_fcgid extends apache
 			if($domain['openbasedir'] == '1')
 			{
 				$openbasedirc = '';
-				$_phpappendopenbasedir = appendOpenBasedirPath($this->settings['system']['mod_fcgid_peardir']);
-				$_phpappendopenbasedir .= appendOpenBasedirPath($this->settings['system']['phpappendopenbasedir']);
+				$_phpappendopenbasedir = '';
+
+				$_custom_openbasedir = explode(':', $this->settings['system']['mod_fcgid_peardir']);
+				foreach($_custom_openbasedir as $cobd)
+				{
+					$_phpappendopenbasedir .= appendOpenBasedirPath($cobd);
+				}
 				
+				$_custom_openbasedir = explode(':', $this->settings['system']['phpappendopenbasedir']);
+				foreach($_custom_openbasedir as $cobd)
+				{
+					$_phpappendopenbasedir .= appendOpenBasedirPath($cobd);
+				}
+
 				if($domain['openbasedir_path'] == '0' && strstr($domain['documentroot'], ":") === false)
 				{
 					$openbasedir = appendOpenBasedirPath($domain['documentroot'], true);
