@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 957 2010-05-19 12:29:32Z EleRas $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1067 2010-06-08 11:13:22Z d00p $
  */
 
 /*
@@ -283,10 +283,18 @@ class lighttpd
 				if((int)$domain['parentdomainid'] == 0)
 				{
 					$vhost_no = '51';
+					if($ssl == '1')
+					{
+						$vhost_no = '61';
+					}
 				}
 				else
 				{
 					$vhost_no = '50';
+					if($ssl == '1')
+					{
+						$vhost_no = '60';
+					}
 				}
 
 				$vhost_filename = makeCorrectFile($this->settings['system']['apacheconf_vhost'].'/vhosts/'.$vhost_no.'_'.$domain['domain'].'.conf');
@@ -368,14 +376,22 @@ class lighttpd
 		}
 		else
 		{
-			mkDirWithCorrectOwnership($domain['customerroot'], $domain['documentroot'], $domain['guid'], $domain['guid'], true);
+			mkDirWithCorrectOwnership($domain['customerroot'], $domain['documentroot'], $domain['guid'], $domain['guid'], true, true);
 
+			$only_webroot = false;
+			if($ssl_vhost === false && $domain['ssl_redirect'] == '1')
+			{
+				$only_webroot = true;
+			}
 			$vhost_content.= $this->getWebroot($domain, $ssl_vhost);
-			$vhost_content.= $this->create_htaccess($domain);
-			$vhost_content.= $this->create_pathOptions($domain);
-			$vhost_content.= $this->composePhpOptions($domain);
-			$vhost_content.= $this->getStats($domain);
-			$vhost_content.= $this->getLogFiles($domain);
+			if(!$only_webroot)
+			{
+				$vhost_content.= $this->create_htaccess($domain);
+				$vhost_content.= $this->create_pathOptions($domain);
+				$vhost_content.= $this->composePhpOptions($domain);
+				$vhost_content.= $this->getStats($domain);
+				$vhost_content.= $this->getLogFiles($domain);
+			}
 		}
 
 		if ($domain['specialsettings'] != "") {
