@@ -14,9 +14,51 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_traffic.inc.functions.php 926 2010-05-10 12:18:12Z d00p $
+ * @version    $Id: cron_traffic.inc.functions.php 1068 2010-06-08 20:39:21Z d00p $
  */
 
+/**
+ * chowns either awstats or webalizer folder,
+ * either with webserver-user or - if fcgid
+ * is used - the customers name, #258
+ * 
+ * @param array $row array if panel_customers
+ * 
+ * @return void
+ */
+function makeChownWithNewStats($row)
+{
+	global $settings;
+
+	// get correct user
+	if($settings['system']['mod_fcgid'] == 1)
+	{
+		$user = $row['loginname'];
+		$group = $row['loginname'];
+	}
+	else
+	{
+		$user = $row['guid'];
+		$group = $row['guid'];
+	}
+
+	// get correct directory
+	$dir = $row['documentroot'];
+	if($settings['system']['awstats_enabled'] == '1')
+	{
+		$dir .= '/awstats/';
+	} else {
+		$dir .= '/webalizer/';
+	}
+
+	// only run chown if directory exists
+	if (file_exists($dir))
+	{
+		// run chown
+		safe_exec('chown -R '.escapeshellarg($user).':'.escapeshellarg($group).' '.escapeshellarg(makeCorrectDir($dir)));
+	}
+}
+
 function awstatsDoSingleDomain($domain, $outputdir)
 {
 	global $cronlog, $settings;
