@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_traffic.php 862 2010-05-01 12:37:05Z EleRas $
+ * @version    $Id: cron_traffic.php 1060 2010-06-08 05:53:07Z d00p $
  */
 
 openRootDB($debugHandler, $lockfile);
@@ -173,7 +173,7 @@ while($row = $db->fetch_array($result))
 				{
 					$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'] . '-' . $domain, $row['documentroot'] . '/webalizer/' . $domain . '/', $domain, $domainlist[$row['customerid']]));
 				}
-			}
+			}			
 		}
 
 		reset($domainlist[$row['customerid']]);
@@ -191,6 +191,9 @@ while($row = $db->fetch_array($result))
 		{
 			$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'], $row['documentroot'] . '/webalizer/', $caption, $domainlist[$row['customerid']]));
 		}
+		
+		// make the stuff readable for the customer, #258
+		makeChownWithNewStats($row);
 	}
 
 	/**
